==> open-autonomy-0.3.3.tar.gz: open-autonomy-0.3.3/docs/api/skills/abstract_round_abci/test_tools/abci_app.md <==
<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app"></a>

# packages.valory.skills.abstract`_`round`_`abci.test`_`tools.abci`_`app

ABCI App test tools.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundA"></a>

## ConcreteRoundA Objects

```python
class ConcreteRoundA(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundA.end_block"></a>

#### end`_`block

```python
def end_block() -> Tuple[MagicMock, MagicMock]
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundA.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_a'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundA.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_a'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundB"></a>

## ConcreteRoundB Objects

```python
class ConcreteRoundB(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundB.end_block"></a>

#### end`_`block

```python
def end_block() -> None
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundB.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_b'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundB.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_b'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundC"></a>

## ConcreteRoundC Objects

```python
class ConcreteRoundC(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundC.end_block"></a>

#### end`_`block

```python
def end_block() -> None
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundC.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_c'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundC.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_c'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.AbciAppTest"></a>

## AbciAppTest Objects

```python
class AbciAppTest(AbciApp[str])
```

A dummy AbciApp for testing purposes.

==> open-autonomy-0.4.0.tar.gz: open-autonomy-0.4.0/docs/api/skills/abstract_round_abci/test_tools/abci_app.md <==
<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app"></a>

# packages.valory.skills.abstract`_`round`_`abci.test`_`tools.abci`_`app

ABCI App test tools.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundA"></a>

## ConcreteRoundA Objects

```python
class ConcreteRoundA(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundA.end_block"></a>

#### end`_`block

```python
def end_block() -> Tuple[MagicMock, MagicMock]
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundA.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_a'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundA.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_a'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundB"></a>

## ConcreteRoundB Objects

```python
class ConcreteRoundB(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundB.end_block"></a>

#### end`_`block

```python
def end_block() -> None
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundB.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_b'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundB.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_b'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundC"></a>

## ConcreteRoundC Objects

```python
class ConcreteRoundC(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundC.end_block"></a>

#### end`_`block

```python
def end_block() -> None
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundC.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_c'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteRoundC.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_c'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteBackgroundRound"></a>

## ConcreteBackgroundRound Objects

```python
class ConcreteBackgroundRound(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteBackgroundRound.end_block"></a>

#### end`_`block

```python
def end_block() -> None
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteBackgroundRound.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_background_c'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteBackgroundRound.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_background_c'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundA"></a>

## ConcreteTerminationRoundA Objects

```python
class ConcreteTerminationRoundA(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundA.end_block"></a>

#### end`_`block

```python
def end_block() -> Tuple[MagicMock, MagicMock]
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundA.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_termination_a'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundA.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_termination_a'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundB"></a>

## ConcreteTerminationRoundB Objects

```python
class ConcreteTerminationRoundB(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundB.end_block"></a>

#### end`_`block

```python
def end_block() -> None
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundB.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_termination_b'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundB.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_termination_b'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundC"></a>

## ConcreteTerminationRoundC Objects

```python
class ConcreteTerminationRoundC(AbstractRound)
```

Dummy instantiation of the AbstractRound class.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundC.end_block"></a>

#### end`_`block

```python
def end_block() -> None
```

End block.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundC.check_payload"></a>

#### check`_`payload

```python
def check_payload(payload: BaseTxPayload) -> None
```

Check payloads of type 'payload_termination_c'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteTerminationRoundC.process_payload"></a>

#### process`_`payload

```python
def process_payload(payload: BaseTxPayload) -> None
```

Process payloads of type 'payload_termination_c'.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.ConcreteEvents"></a>

## ConcreteEvents Objects

```python
class ConcreteEvents(Events)
```

Defines dummy events to be used for testing purposes.

<a id="packages.valory.skills.abstract_round_abci.test_tools.abci_app.AbciAppTest"></a>

## AbciAppTest Objects

```python
class AbciAppTest(AbciApp[str])
```

A dummy AbciApp for testing purposes.
